@@ -1,30 +1,31 @@
-import sys
 import itertools
 import collections
 
 import networkx as nx
 
-from irco import models, logging
+
+from irco import logging
 
 log = logging.get_logger()
 
 
+
 def get_institutions(publication):
     institutions = set()
 
-    for institution in publication.institutions:
-        institutions.add(institution.name)
+    for affiliation in publication.affiliations:
+        institutions.add(affiliation.institution.name)
 
     return institutions
 
 
-def create(session, criteria):
+def create(session, publications):
     g = nx.Graph()
 
     papers_count = collections.Counter()
     collaborations_count = collections.Counter()
 
-    for publication in session.query(models.Publication).filter(criteria):
+    for publication in publications:
         institutions = get_institutions(publication)
         g.add_nodes_from(institutions)
         papers_count.update(institutions)
